@@ -17,14 +17,14 @@
 #'
 #' An arbitrary number of additional columns containing aesthetic or data
 #' attributes can be part of the edf, so long as they follow the aforementioned
-#' columns.
+#' columns. Some examples are included in [edge_aes()]
 #'
 #' @param from A vector of node ID values from which edges are outbound. The
 #'   vector length must equal that of the `to` vector.
 #' @param to A vector of node ID values to which edges are incoming. The vector
 #'   length must equal that of the `from` vector.
 #' @param rel An optional `rel` label for each edge.
-#' @param ... One or more vectors for associated edge attributes.
+#' @param ... One or more vectors for associated edge attributes. Can be some of [edge_aes()]
 #'
 #' @return An edge data frame (edf).
 #'
@@ -55,7 +55,7 @@
 #' # Display the edge data frame
 #' edf
 #'
-#' @family Edge creation and removal
+#' @family edge creation and removal
 #' @export
 create_edge_df <- function(
     from,
@@ -78,7 +78,7 @@ create_edge_df <- function(
   # if `rel` is NULL, create character vector with
   # NA values; class as character otherwise
   if (is.null(rel)) {
-    rel <- rep(as.character(NA), length(from))
+    rel <- rep(NA_character_, length(from))
   } else {
     rel <- as.character(rel)
   }
@@ -92,18 +92,18 @@ create_edge_df <- function(
 
     # Expand vectors with `length` > `1` and
     # `length` < `length(from)`
-    if (length(rel) > 1 &
+    if (length(rel) > 1 &&
         length(rel) < length(from)) {
       rel <-
         c(rel,
-          rep(as.character(NA),
+          rep(NA_character_,
               (length(from) - length(rel))))
     }
 
     # Trim vectors with number of values exceeding
     # the number of edges
     if (length(rel) > length(from)) {
-      rel <- rel[1:length(from)]
+      rel <- rel[seq_along(from)]
     }
   }
 
@@ -111,7 +111,7 @@ create_edge_df <- function(
   extras <- list(...)
 
   if (length(extras) > 0) {
-    for (i in 1:length(extras)) {
+    for (i in seq_along(extras)) {
 
       # Expand vectors with single values to fill to
       # the number of edges
@@ -121,11 +121,11 @@ create_edge_df <- function(
 
       # Expand vectors with `length` > `1` and
       # `length` < `length(from)`
-      if (length(extras[[i]]) > 1 &
+      if (length(extras[[i]]) > 1 &&
           length(extras[[i]]) < length(from)) {
         extras[[i]] <-
           c(extras[[i]],
-            rep(as.character(NA),
+            rep(NA_character_,
                 (length(from) -
                    length(extras[[i]]))))
       }
@@ -133,7 +133,7 @@ create_edge_df <- function(
       # Trim vectors with number of values exceeding
       # the number of edges
       if (length(extras[[i]]) > length(from)) {
-        extras[[i]] <- extras[[i]][1:length(from)]
+        extras[[i]] <- extras[[i]][seq_along(from)]
       }
     }
 
@@ -147,7 +147,7 @@ create_edge_df <- function(
     edges_df <-
       dplyr::bind_cols(
         data.frame(
-          id = 1:n,
+          id = seq_len(n),
           from = from,
           to = to,
           rel = rel,
@@ -156,7 +156,7 @@ create_edge_df <- function(
   } else {
     edges_df <-
       data.frame(
-        id = 1:n,
+        id = seq_len(n),
         from = from,
         to = to,
         rel = rel,
