@@ -35,19 +35,11 @@
 #' @export
 is_graph_undirected <- function(graph) {
 
-  # Get the name of the function
-  fcn_name <- get_calling_fcn()
-
   # Validation: Graph object is valid
-  if (graph_object_valid(graph) == FALSE) {
-
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The graph object is not valid")
-  }
+  check_graph_valid(graph)
 
   # Determine if graph is
   # undirected by using a
   # statement with `graph$directed`
-  graph$directed == FALSE
+  !graph$directed
 }
