@@ -61,9 +61,8 @@
 #' # new node attribute
 #' graph %>% get_edge_df()
 #'
-#' @family Edge creation and removal
+#' @family edge creation and removal
 #'
-#' @import rlang
 #' @export
 recode_edge_attrs <- function(
     graph,
@@ -76,24 +75,11 @@ recode_edge_attrs <- function(
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  # Get the name of the function
-  fcn_name <- get_calling_fcn()
-
   # Validation: Graph object is valid
-  if (graph_object_valid(graph) == FALSE) {
-
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The graph object is not valid")
-  }
+  check_graph_valid(graph)
 
   # Validation: Graph contains edges
-  if (graph_contains_edges(graph) == FALSE) {
-
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The graph contains no edges")
-  }
+  check_graph_contains_edges(graph)
 
   # Get the requested `edge_attr_from`
   edge_attr_from <-
@@ -121,9 +107,8 @@ recode_edge_attrs <- function(
   # of the graph's edge attributes
   if (!any(column_names_graph %in% edge_attr_from)) {
 
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The edge attribute to recode is not in the edf")
+    cli::cli_abort(
+      "The edge attribute to recode is not in the edf.")
   }
 
   # Get the column number for the edge attr to recode
@@ -140,7 +125,7 @@ recode_edge_attrs <- function(
   indices_stack <- vector("numeric")
 
   # Parse the recoding pairs
-  for (i in 1:length(replacements)) {
+  for (i in seq_along(replacements)) {
 
     pairing <-
       trimws(unlist(stringr::str_split(replacements[[i]], "->")))
@@ -161,7 +146,7 @@ recode_edge_attrs <- function(
   if (!is.null(otherwise)) {
 
     otherwise_indices <-
-      which(!(1:nrow(edges) %in% indices_stack))
+      which(!(seq_len(nrow(edges)) %in% indices_stack))
 
     if (length(otherwise_indices) > 0) {
       vector_to_recode[otherwise_indices] <-
@@ -178,9 +163,8 @@ recode_edge_attrs <- function(
     # `from` or `to`
     if (any(c("from", "to") %in% edge_attr_to)) {
 
-      emit_error(
-        fcn_name = fcn_name,
-        reasons = "You cannot use the names `from` or `to`")
+      cli::cli_abort(
+        "You cannot use the names `from` or `to`.")
     }
 
     if (any(column_names_graph %in% edge_attr_to)) {
@@ -216,11 +200,14 @@ recode_edge_attrs <- function(
   # with the `edges` object
   graph$edges_df <- edges
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
-      version_id = nrow(graph$graph_log) + 1,
+      version_id = nrow(graph$graph_log) + 1L,
       function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
