@@ -81,7 +81,6 @@
 #' # `3`->`1` have values for `value` > 3.0
 #' graph %>% get_selection()
 #'
-#' @import rlang
 #' @export
 select_edges <- function(
     graph,
@@ -95,47 +94,23 @@ select_edges <- function(
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  # Get the name of the function
-  fcn_name <- get_calling_fcn()
-
   # Validation: Graph object is valid
-  if (graph_object_valid(graph) == FALSE) {
-
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The graph object is not valid")
-  }
+  check_graph_valid(graph)
 
   # Validation: Graph contains nodes
-  if (graph_contains_nodes(graph) == FALSE) {
-
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The graph contains no nodes")
-  }
+  check_graph_contains_nodes(graph)
 
   # Validation: Graph contains edges
-  if (graph_contains_edges(graph) == FALSE) {
-
-    emit_error(
-      fcn_name = fcn_name,
-      reasons = "The graph contains no edges")
-  }
+  check_graph_contains_edges(graph)
 
   # Stop function if `edges` refers to edge ID
   # values that are not in the graph
-  if (!is.null(edges)) {
-    if (!any(edges %in% graph$edges_df$id)) {
+  if (!is.null(edges) && !any(edges %in% graph$edges_df$id)) {
 
-      emit_error(
-        fcn_name = fcn_name,
-        reasons = "The values provided in `edges` do not all correspond to edge ID values in the graph")
-    }
+    cli::cli_abort(
+      "The values provided in `edges` do not all correspond to edge ID values in the graph.")
   }
 
-  # Capture provided conditions
-  conditions <- rlang::enquo(conditions)
-
   # Extract the graph's internal edf
   edges_df <- graph$edges_df
 
@@ -147,22 +122,19 @@ select_edges <- function(
   # If conditions are provided then
   # pass in those conditions and filter the
   # data frame of `edges_df`
-  if (!is.null(
-    rlang::enquo(conditions) %>%
-    rlang::get_expr())) {
+  if (!rlang::quo_is_null(rlang::enquo(conditions))) {
 
-    edges_df <- dplyr::filter(.data = edges_df, !!conditions)
+    edges_df <- dplyr::filter(.data = edges_df, {{ conditions }})
   }
 
   # If a `from` vector provided, filter the edf
   # to get those edges where the specified node IDs
   # are present
   if (!is.null(from)) {
-    if (any(!(from %in% edges_df$from))) {
+    if (!all(from %in% edges_df$from)) {
 
-      emit_error(
-        fcn_name = fcn_name,
-        reasons = "One of more of the nodes specified as `from` not part of an edge")
+      cli::cli_abort(
+        "One of more of the nodes specified as `from` not part of an edge.")
     }
 
     from_val <- from
@@ -176,11 +148,10 @@ select_edges <- function(
   # to get those edges where the specified node IDs
   # are present
   if (!is.null(to)) {
-    if (any(!(to %in% edges_df$to))) {
+    if (!all(to %in% edges_df$to)) {
 
-      emit_error(
-        fcn_name = fcn_name,
-        reasons = "One of more of the nodes specified as `to` are not part of an edge")
+      cli::cli_abort(
+        "One of more of the nodes specified as `to` are not part of an edge.")
     }
 
     to_val <- to
@@ -193,8 +164,7 @@ select_edges <- function(
   # Select only the `id`, `to`, and `from` columns
   edges_selected <-
     edges_df %>%
-    dplyr::select(id, from, to) %>%
-    dplyr::rename(edge = id)
+    dplyr::select(edge = "id", "from", "to")
 
   # Create an integer vector representing edges
   edges_selected <- edges_selected$edge
@@ -226,8 +196,7 @@ select_edges <- function(
   edges_combined <-
     graph$edges_df %>%
     dplyr::filter(id %in% edges_combined) %>%
-    dplyr::select(id, from, to) %>%
-    dplyr::rename(edge = id)
+    dplyr::select(edge = "id", "from", "to")
 
   # Add the edge ID values to the active selection
   # of nodes in `graph$node_selection`
@@ -241,11 +210,14 @@ select_edges <- function(
   n_e_select_properties_out <-
     node_edge_selection_properties(graph = graph)
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
-      version_id = nrow(graph$graph_log) + 1,
+      version_id = nrow(graph$graph_log) + 1L,
       function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
@@ -263,7 +235,7 @@ select_edges <- function(
       graph$graph_info$display_msgs) {
 
     # Construct message body
-    if (!n_e_select_properties_in[["node_selection_available"]] &
+    if (!n_e_select_properties_in[["node_selection_available"]] &&
         !n_e_select_properties_in[["edge_selection_available"]]) {
 
       msg_body <-
@@ -271,7 +243,7 @@ select_edges <- function(
           "created a new selection of \\
         {n_e_select_properties_out[['selection_count_str']]}")
 
-    } else if (n_e_select_properties_in[["node_selection_available"]] |
+    } else if (n_e_select_properties_in[["node_selection_available"]] ||
                n_e_select_properties_in[["edge_selection_available"]]) {
 
       if (n_e_select_properties_in[["edge_selection_available"]]) {
